Processor.App.OutStreamer.stream_to_file.OutStreamerFileDefault — CommonCrawl Extractor 1.0 documentation

Toggle navigation sidebar
Toggle in-page Table of Contents

# Processor.App.OutStreamer.stream_to_file.OutStreamerFileDefault

class Processor.App.OutStreamer.stream_to_file.OutStreamerFileDefault(origin: Path, extension: str = '.out', directory_prefix: str = 'directory_', max_directory_size: int = 500, order_num: bool = True, max_retries: int = 3)
  __init__(origin: Path, extension: str = '.out', directory_prefix: str = 'directory_', max_directory_size: int = 500, order_num: bool = True, max_retries: int = 3)

  Methods

  `__init__`(origin[, extension, ...]) |
  `clean_up`() |
  `get_file_name`(metadata) |
  `metadata_to_string`(extracted_data) |
  `stream`(extracted_data, metadata) |